@@ -125,6 +125,10 @@ def config(
         1,
         help="The maximum number of cores to use in the ancient damage estimation.",
     ),
+    cores_pr_fit: int = typer.Option(
+        1,
+        help="Number of cores pr. fit. Do not change unless you know what you are doing.",
+    ),
     config_path: Path = typer.Option(
         config_path_default,
         help="The name of the config file. ",
@@ -171,6 +175,7 @@ def config(
             #
             "dir": storage_dir,
             "cores": cores,
+            "cores_pr_fit": cores_pr_fit,
             "bayesian": bayesian,
             "config_path": str(config_path),
         }
@@ -191,12 +196,20 @@ def compute(
         help="Path to the config-file.",
     ),
 ):
-    """Compute the LCA and Ancient Damage given the configuration."""
+    """Compute the LCA and Ancient Damage given the configuration file."""
 
     from metaDMG import utils
-    from metaDMG.fit import run_workflow
+    from metaDMG.fit import run_workflow, get_logger_port_and_path, setup_logger
 
-    config = utils.load_config(config_path)
+    log_port, log_path = get_logger_port_and_path()
+
+    setup_logger(log_port=log_port, log_path=log_path)
+
+    config = utils.load_config(
+        config_path=config_path,
+        log_port=log_port,
+        log_path=log_path,
+    )
 
     run_workflow(config)
 
@@ -212,8 +225,8 @@ def dashboard(
         file_okay=True,
         help="Path to the config-file.",
     ),
-    results_dir: Path = typer.Option(
-        results_dir_default,
+    results: Optional[Path] = typer.Option(
+        None,
         help="Path to the results directory.",
     ),
     debug: bool = typer.Option(
@@ -231,6 +244,7 @@ def dashboard(
     ),
 ):
     """Visualise the results in an interactive dashboard.
+    Requires metaDMG-viz to be installed.
 
     run as e.g.:
 
@@ -244,10 +258,20 @@ def dashboard(
 
     """
 
-    from metaDMG_viz import start_dashboard
+    try:
+        from metaDMG_viz import start_dashboard
+    except ModuleNotFoundError:
+        print("""metaDMG-viz has to be installed: pip install "metaDMG[all]" """)
+        typer.Abort()
+
+    from metaDMG.utils import get_results_dir
+
+    results_dir = get_results_dir(
+        config_path=config_path,
+        results_dir=results,
+    )
 
     start_dashboard(
-        config_path=config_path,
         results_dir=results_dir,
         debug=debug,
         host=host,
@@ -260,13 +284,13 @@ def dashboard(
 
 @cli_app.command("filter")
 def filter(
-    config_path: Optional[Path] = typer.Argument(
+    config: Optional[Path] = typer.Argument(
         None,
         file_okay=True,
         help="Path to the config-file.",
     ),
-    results_dir: Optional[Path] = typer.Option(
-        results_dir_default,
+    results: Optional[Path] = typer.Option(
+        None,
         help="Path to the results directory.",
     ),
     output: Path = typer.Option(
@@ -285,8 +309,8 @@ def filter(
     filter_and_save_results(
         output=output,
         query=query,
-        config_path=config_path,
-        results_dir=results_dir,
+        config_path=config,
+        results_dir=results,
     )
 
 
@@ -295,13 +319,13 @@ def filter(
 
 @cli_app.command("convert")
 def convert(
-    config_path: Optional[Path] = typer.Argument(
+    config: Optional[Path] = typer.Argument(
         None,
         file_okay=True,
         help="Path to the config-file.",
     ),
-    results_dir: Optional[Path] = typer.Option(
-        results_dir_default,
+    results: Optional[Path] = typer.Option(
+        None,
         help="Path to the results directory.",
     ),
     output: Path = typer.Option(
@@ -316,8 +340,8 @@ def convert(
     filter_and_save_results(
         output=output,
         query="",
-        config_path=config_path,
-        results_dir=results_dir,
+        config_path=config,
+        results_dir=results,
     )
 
 
