@@ -68,6 +68,25 @@ def add_count_information(config, fit_result, group, data):
 #%%
 
 
+def timer_fit_MAP(config, data):
+    # data = group_to_numpyro_data(config, group)
+    # %timeit timer_fit_MAP(config, data)
+    fit_result = {}
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore")
+        fit_all, fit_forward, fit_reverse = frequentist.make_fits(fit_result, data)
+
+
+def timer_fit_bayesian(config, data, mcmc_PMD, mcmc_null):
+    # data = group_to_numpyro_data(config, group)
+    # %timeit timer_fit_bayesian(config, data, mcmc_PMD, mcmc_null)
+    fit_result = {}
+    bayesian.make_fits(fit_result, data, mcmc_PMD, mcmc_null)
+
+
+#%%
+
+
 def fit_single_group(
     config,
     group,
@@ -118,9 +137,17 @@ def compute_fits_seriel(config, df_mismatches, with_progressbar=False):
                 mcmc_PMD,
                 mcmc_null,
             )
-        except Exception as e:
+        except AttributeError:
             sample = config["sample"]
-            logger.exception(f"Error occured fitting Tax ID: {tax_id} in sample {sample}.")
+            logger.exception(
+                f"Error occured fitting Tax ID: {tax_id} in sample {sample}."
+            )
+
+        except Exception:
+            sample = config["sample"]
+            logger.exception(
+                f"Error occured fitting Tax ID: {tax_id} in sample {sample}."
+            )
 
     return d_fit_results
 
